import java.net.Socket;
import java.net.URL;

/**
 * Class Proxy provides methods customized for regular proxy usage of UsaProxy.
 */
public class Proxy implements ProxyType {
	
	public URL requestURL;

	/**
     *  Returns a Socket with the host and optionally port specified in the field requestURL
     *  
     *  @return the Socket
     */
	public Socket getServerConnect() throws Exception {
		
		int port 	= 80;
		
		/** Could port be detected ? */
		if (requestURL.getPort() > 0) {
		    port = requestURL.getPort();
		}
		
		return new Socket(requestURL.getHost(), port);
	}

	/**
     *  Returns the request line.
     *  <br><br>
     *  The URL is reduced to a relative file path. HTTP version 1.0 is added.
     *  
     *  @param method is the request method
     *  @param url is the requested URL
     *  @return the request String
     */
	public String getRequestLine(String method, URL url) {
		return method + " " + url.getFile() + " HTTP/1.0";
	}
	
	/**
     *  Returns the script String in the form of a script tag with the proxyscript.js as src attribute.
     *  The virtual name lo.lo is used as host.
     *  
     *  @return the script String
     */
	public String getScriptString() {
		return "<script src='http://lo.lo/usaproxylolo/proxyscript.js' type='text/javascript'></script>";
	}

	/**
	 * Sets the requested URL
	 * 
	 * @param url is the requestURL to set.
	 */
	public void setRequestURL(URL url) {
		this.requestURL = url;
	}
	
	/** not implemented by Proxy */
	public String getHostName() { return ""; }

}
