import java.net.InetAddress;
import java.net.Socket;
import java.net.URL;

/** Class TransparentProxy provides methods which are specifically defined for
 *  the case UsaProxy is used as transparent proxy
 */
public class TransparentProxy implements ProxyType {
	
	private InetAddress		serverAddress;
	private int 			serverPort;						  /** server port */
	
	/** Constructor, creates a TransparentProxy.
     */
	public TransparentProxy() {
		super();
	}
	
	/** Constructor, creates a TransparentProxy with the given server information.
	 * 
	 * @param serverAddress is the server address
	 * @param serverPort is the port of the web server
     */
	public TransparentProxy(InetAddress serverAddress, int serverPort) {
		super();
		this.serverPort 	= serverPort;
		this.serverAddress 	= serverAddress;
	}
	
	/**
     *  Returns a Socket of the web server.
     *  
     *  @return the Socket
     */
	public Socket getServerConnect() throws Exception {
		return new Socket(serverAddress.getHostName(),serverPort);
	}
	
	/**
     *  Returns the request line.
     *  <br><br>
     *  The URL is reduced to a relative file path. HTTP version 1.0 is added.
     *  
     *  @param method is the request method
     *  @param url is the requested URL
     *  @return the request String
     */
	public String getRequestLine(String method, URL url) {
		return method + " " + url.getFile() + " HTTP/1.0";
	}
	
	/**
     *  Returns the script String in the form of a script tag with the proxyscript.js as src attribute.
     *  The virtual name lo.lo is used as host.
     *  
     *  @return the script String
     */
	public String getScriptString() {
		return "<script src='http://lo.lo/usaproxylolo/proxyscript.js' type='text/javascript'></script>";
	}

	/** not implemented by TransparentProxy */
	public void setRequestURL(URL url) {}
	
	/** not implemented by TransparentProxy */
	public String getHostName() { return ""; }

}
